---
title: "Introduction"
type: Chapter
slug: true
front: false
---

>> The real long-term future of computing consists of figuring out how to make the best possible use we can out of the literal millions of devices which already exist.

<cite>(Solderpunk, 2020, Cited in de Valk, 2022)</cite>

Beware! If you’ve picked up this publication expecting to learn how to make a flawless, DAW-less, in tune and always working polysynth, think again. However, if you, like me, are interested in making screamy, dreamy, noise boxes using an alternative resource: trash, you’ve come to the right place.

When I first read about salvage computing, I got very excited. Being part of the DIY Sound community, I’ve developed a growing discomfort with some aspects of the practice. Over the past few years, I’ve hosted workshops around circuit bending[^circuit-bending] and LOFI sound devices in and around Rotterdam. These workshops are meant as an accessible way to get people tinkering with electronics, through something infinitely playful: making instruments[^playful].

[^circuit-bending]: the practice around hacking discarded toys to find sonic potential through creating shorts, or sometimes literally bending the circuit.

[^playful]: Making instruments is an engaging way to learn about and work with the flow of electricity

In an ecosystem where a printer is only printing with a costly subscription [^printer-subscription], disruptive products become obsolete within a year[^AI-pin], fixing flat tires is outsourced [^swapfiets] and some smartphones literally have to be frozen [^frozen] to be able to replace the battery, it’s clear we’re no longer in charge of our own devices. Warranty-void stickers and lengthy terms and conditions scare us into compliance. I’ve noticed how empowering these first-time soldering workshops can be in taking back this autonomy by making (or breaking) a circuit together. They are a shared attempt to uncover some of the black boxes in our own products [@hertzZombieMediaCircuit2012]. However, the toys and materials used in the workshops are single-use [^single-use] and, with ease, thrown out afterward. The carelessness notion creeps in that waste has no value, and is easily replaceable, and broke my heart a bit, one workshop at a time.

[^printer-subscription]: HP’s “all-inclusive” printers can only be used with an active subscription [@hachmanNightmareRealHP2024].

[^AI-pin]: Humane Inc. Ai Pin closed their servers within one year after releasing their *A.I. Pin*. Now, you can only ask this piece of hardware how many batteries it has left. [@chokkattuWhatYourDefunct2025]

[^swapfiets]: Swapfiets promote their bike subscriptions as “We give you a bike that you never have to repair”

[^frozen]: The Nothing Phone scored a 1/10 in iFixit's repairability score [@havardEssentialPhoneTeardown2017]

[^single-use]: and often required much preparation in terms of collecting, transporting, repairing, testing, and cleaning.

This is where the field guide comes into play: Can we shift the practice of playful tinkering to acknowledge, rather than ignore, the waste streams they are part of? Limiting ourselves to only use salvaged components and discovering; is it possible to live off (create with) electronic components salvaged in the wild? And what would such a practice entail?

Because salvage is not just about reusing materials; but about confronting the systems that created the waste in the first place. Waste is not only obsolete media but also the by-product of the entire production lifecycle of an electronic product; From the mining of minerals that make up the hardware to the inevitable disposal site [@gabrysSalvage2012]. Since the rate at which waste is collected and recycled isn't growing at the same pace as our collective buying and production, the landfills will continue to grow. Parikka even goes as far to say as that recycling is ultimately "trade-waste", where our abandoned devices are shipped across the ocean [@parikkaDustMatter2012].

## Beyond the kit
The preference for buying new is noticeable in the DIY synth community as well. When publishing a project, it's common to share a pre-filled webshop cart along with the schematics or even sell it as a pre-compiled kit[^KIT]. To me, this goes against the ethos of DIY, which is about making do with what you have, with a focus on doing, and not the "thing" [@hertzArtDIYElectronics2023]. Instead, a whole new market is created consisting of Lego-like kits. These kits gloss over the actual challenges and difficulties of creating sound boxes, preventing the development of much-needed problem-solving skills, and not actually discovering anything new [@CooperativeExperimentalismSharing].

[^KIT]: ![Kit from Bastl Instruments](/assets/chapters/bastl_kit.webp)

<ins>Echt foto's maken...</ins>

![A sound box](https://placehold.co/600x400){.img--fullpage}

Instead, what you will learn to build using this guide, is a starting point. Small electronic circuits that make sound on their own, but as you learn more about electronic thinkering, you can also duplicate, manipulate, and modulate into something entirely different.

<ins>plz explain that this text not only explores the questions above, but also wants to share insights with others, what this text is (field guide with a twist), for who it is meant (in a little more detail than the very first paragraph) and in which context it is written (the grad project)? (that would situate the text and answer some of the questions Aymeric had while reading).</ins>


The guide is split up into five chapters, each focusing on a different stage of salvaging for sound devices:

#### 1. Gathering hardware
*We'll go through which devices work for salvaging, and where to find them. And talk about dealing with hidden waste streams and obsolescence.*
oke dit gaat over de waste streams en waarom dingen weggeooien: over dat bedrijven strategieen in place hebben om je het idee te geven dat je je spullen moet upgraden

#### 2. Dismantling devices
Discovery of strategies that manufacturers use to keep you out of their devices
hier gaat het weer meer over black boxing en planned obsolesence, dus dat het sowieso stuk gaat i guess
En ook over de service manual

#### 3. Components to salvage
*An overview of parts to salvage, how to identify them, and how to reuse them*
Hier gaan we dan door te kijken naar componenten zien hoe de planned obsolesence in elkaar steekt

#### 4. Recipes for making
*strategies for making with salvaged parts, and ways to modify the devices.*

#### 5. Taking inventory
*Cleaning up the inventory and looking back*

Happy scavenging!

<ins> Introduce yourself first (if you haven't already by giving more context about your project above). Describe your practice and what you bring to this guide (experience as a live coder, musician, designer etc. THEN you can give a disclaimer about not being an expert in electronics (you are an expert in many other fields and this expertise makes this field guide so interesting!</ins>

On that note, I am by no means an expert in electronics. When I write about how things work, please take it with a grain of salt. This guide represents my personal understanding, which, no doubt, contains incorrect assumptions or oversimplifications. When in doubt, ask a friend!
